/*******************************************************************************
* File Name: SysTick_PM.c
* Version 2.80
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "SysTick.h"

static SysTick_backupStruct SysTick_backup;


/*******************************************************************************
* Function Name: SysTick_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SysTick_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void SysTick_SaveConfig(void) 
{
    #if (!SysTick_UsingFixedFunction)
        SysTick_backup.TimerUdb = SysTick_ReadCounter();
        SysTick_backup.InterruptMaskValue = SysTick_STATUS_MASK;
        #if (SysTick_UsingHWCaptureCounter)
            SysTick_backup.TimerCaptureCounter = SysTick_ReadCaptureCount();
        #endif /* Back Up capture counter register  */

        #if(!SysTick_UDB_CONTROL_REG_REMOVED)
            SysTick_backup.TimerControlRegister = SysTick_ReadControlRegister();
        #endif /* Backup the enable state of the Timer component */
    #endif /* Backup non retention registers in UDB implementation. All fixed function registers are retention */
}


/*******************************************************************************
* Function Name: SysTick_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SysTick_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void SysTick_RestoreConfig(void) 
{   
    #if (!SysTick_UsingFixedFunction)

        SysTick_WriteCounter(SysTick_backup.TimerUdb);
        SysTick_STATUS_MASK =SysTick_backup.InterruptMaskValue;
        #if (SysTick_UsingHWCaptureCounter)
            SysTick_SetCaptureCount(SysTick_backup.TimerCaptureCounter);
        #endif /* Restore Capture counter register*/

        #if(!SysTick_UDB_CONTROL_REG_REMOVED)
            SysTick_WriteControlRegister(SysTick_backup.TimerControlRegister);
        #endif /* Restore the enable state of the Timer component */
    #endif /* Restore non retention registers in the UDB implementation only */
}


/*******************************************************************************
* Function Name: SysTick_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SysTick_backup.TimerEnableState:  Is modified depending on the
*  enable state of the block before entering sleep mode.
*
*******************************************************************************/
void SysTick_Sleep(void) 
{
    #if(!SysTick_UDB_CONTROL_REG_REMOVED)
        /* Save Counter's enable state */
        if(SysTick_CTRL_ENABLE == (SysTick_CONTROL & SysTick_CTRL_ENABLE))
        {
            /* Timer is enabled */
            SysTick_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            SysTick_backup.TimerEnableState = 0u;
        }
    #endif /* Back up enable state from the Timer control register */
    SysTick_Stop();
    SysTick_SaveConfig();
}


/*******************************************************************************
* Function Name: SysTick_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  SysTick_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void SysTick_Wakeup(void) 
{
    SysTick_RestoreConfig();
    #if(!SysTick_UDB_CONTROL_REG_REMOVED)
        if(SysTick_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                SysTick_Enable();
        } /* Do nothing if Timer was disabled before */
    #endif /* Remove this code section if Control register is removed */
}


/* [] END OF FILE */
